package com.logicbig.example;

import java.util.regex.Pattern;

import static com.logicbig.example.RegexUtil.test;


public class RegexExamples {

    public static void main(String[] args) {
        //literal example
        test("in", "Linux");
        //dot examples
        test(".", "a");
        test(".", " ");
        test(".z", "cz");
        test(".z", "cb");
        test(".z", "9z");
        test("..e", "the");
        test("t.e", "the");
        test("...", "the");
        test("i.u", "Linux");
        //character classes
        test("[0-9]", "9");
        test("[[0-9][a-z]]", "t");
        test("[[0-9][^e-z]]", "s");
        test("[a-z][0-9]", "t5");
        test("[jJ][aA][vV][aA]", "jAva");
        test(".[aA][vV][aA]", "mAva");
        test("[jJ][aA].[aA]", "lAva");
        test("[A-Z][a-z].java", "My.java");
        test("[A-Z][a-z].java", "My8java");
        test("[A-Z][a-z]\\.java", "My8java");
        test("[A-Z][a-z]\\.java", "My.java");
        test("[A-Z][a-z][.]java", "My8java");
        test("[A-Z]", "USA");
        test("[1-9][1-9]-[1-9][1-9]", "38-99");

        //predefined classes
        test("\\d", "4");
        test("\\d", "c");
        test("\\D", "a");
        test("\\W", "c");
        test("\\w", " ");
        test("\\d", " ");
        test("\\s", " ");
        test("\\D", " ");
        test("\\W", " ");
        test("\\w", "cd");
        test("\\w\\w", "cd");
        test("[\\D]\\d", "b4");
        test("[a-z]\\s[0-9]", "a 4");
        test("\\D\\d\\w\\W", "w9s4");
        test("\\w\\W", "_@");
        test("\\W", ".");
        test("\\.", ".");

        //boundary matching
        test("^The", "The line");
        test("^The", "This is The line");
        test("line$", "The line");
        test("\\bline", "The line");
        test("is", "This is island");
        test("\\bis", "This is island");
        test("\\bis\\b", "This is island");
        test("line", "The inclined line");
        test("\\bline", "The inclined line");
        test("line\\b", "The inclined line");
        test("lined\\b", "The inclined line");
        test("\\bi", "water is inside inland");
        test("\\bin", "water is inside inland");
        test("^T", "The First line\nThe SecondLine", Pattern.MULTILINE);
        test("^a\\w", "a an \r\napple", Pattern.MULTILINE);//matches at 7-9
        test("\\Aa", "a \napple", Pattern.MULTILINE);//matches at 0-1
        test("\\Ga", "aab 421aa");//matches at 0-1, 1-2

        // logical OR
        test("a|b", "a");
        test("a|b", "alphabet");
        test("[a-d]|[x-z]", "x");
        test("[a-d][x-z]|[^*&%]", "cy%");

        // grouping
        test("(Tim)|(Mike)", "Mike");

        test("(Tim)|(Mike)", "That person is Mike");

        test("(Admin)|(Manager)", "Jan Role is Manager");
        test("[a-z&&([n-q]|[u-x])]", "t");
        test("([1-9]|1[012]):[0-5][0-9]", "3:59");
        test("([1-9]|1[012]):[0-5][0-9]", "3:70");

        test("^(a|b|c)", "beautiful");
    }
}